@@ -18,8 +18,7 @@ import click
 from jsonschema.exceptions import ValidationError
 from reana_commons.config import INTERACTIVE_SESSION_TYPES, REANA_COMPUTE_BACKENDS
 from reana_commons.errors import REANAValidationError
-from reana_commons.operational_options import validate_operational_options
-from reana_commons.utils import click_table_printer
+from reana_commons.validation.operational_options import validate_operational_options
 
 from reana_client.cli.files import get_files, upload_files
 from reana_client.cli.utils import (
@@ -28,27 +27,29 @@ from reana_client.cli.utils import (
     add_pagination_options,
     add_workflow_option,
     check_connection,
-    format_data,
+    display_formatted_output,
     format_session_uri,
     get_formatted_progress,
     human_readable_or_raw_option,
     key_value_to_dict,
     parse_filter_parameters,
-    parse_format_parameters,
     requires_environments,
-    validate_workflow_name_parameter,
 )
 from reana_client.config import ERROR_MESSAGES, RUN_STATUSES, TIMECHECK
 from reana_client.printer import display_message
 from reana_client.utils import (
     get_reana_yaml_file_path,
+    get_workflow_duration,
     get_workflow_name_and_run_number,
     get_workflow_status_change_msg,
     is_uuid_v4,
-    load_reana_spec,
-    validate_input_parameters,
+    load_validate_reana_spec,
     workflow_uuid_or_name,
 )
+from reana_client.validation.utils import (
+    validate_input_parameters,
+    validate_workflow_name_parameter,
+)
 
 
 @click.group(help="Workflow management commands")
@@ -67,7 +68,10 @@ def workflow_execution_group(ctx):
 
 @workflow_management_group.command("list")
 @click.option(
-    "-w", "--workflow", default=None, help="List all runs of the given workflow.",
+    "-w",
+    "--workflow",
+    default=None,
+    help="List all runs of the given workflow.",
 )
 @click.option(
     "-s", "--sessions", is_flag=True, help="List all open interactive sessions."
@@ -91,15 +95,16 @@ def workflow_execution_group(ctx):
 @click.option(
     "--all",
     "show_all",
-    count=True,
-    default=True,
+    is_flag=True,
+    default=False,
     help="Show all workflows including deleted ones.",
 )
 @click.option(
     "-v",
     "--verbose",
     count=True,
-    help="Print out extra information: workflow id, user id, disk usage.",
+    help="Print out extra information: workflow id, user id, disk usage, "
+    "progress, duration.",
 )
 @human_readable_or_raw_option
 @click.option(
@@ -116,6 +121,14 @@ def workflow_execution_group(ctx):
     "Use `--filter <columm_name>=<column_value>` pairs. "
     "Available filters are ``name`` and ``status``.",
 )
+@click.option(
+    "--include-duration",
+    "include_duration",
+    is_flag=True,
+    default=False,
+    help="Include the duration of the workflows in seconds. In case a workflow is in "
+    "progress, its duration as of now will be shown.",
+)
 @click.option(
     "--include-progress",
     "include_progress",
@@ -130,11 +143,18 @@ def workflow_execution_group(ctx):
     default=None,
     help="Include size information of the workspace.",
 )
+@click.option(
+    "--show-deleted-runs",
+    "show_deleted_runs",
+    is_flag=True,
+    default=False,
+    help="Include deleted workflows in the output.",
+)
 @add_access_token_options
 @add_pagination_options
 @check_connection
 @click.pass_context
-def workflow_workflows(  # noqa: C901
+def workflows_list(  # noqa: C901
     ctx,
     workflow,
     sessions,
@@ -148,8 +168,10 @@ def workflow_workflows(  # noqa: C901
     page,
     size,
     filters,
+    include_duration: bool,
     include_progress,
     include_workspace_size,
+    show_deleted_runs: bool,
 ):  # noqa: D301
     """List all workflows and sessions.
 
@@ -158,12 +180,11 @@ def workflow_workflows(  # noqa: C901
     interactive sessions, you need to pass the ``--sessions`` command-line
     option.
 
-    Example: \n
-    \t $ reana-client list --all \n
-    \t $ reana-client list --sessions \n
+    Example:\n
+    \t $ reana-client list --all\n
+    \t $ reana-client list --sessions\n
     \t $ reana-client list --verbose --bytes
     """
-    import tablib
     from reana_client.api.client import get_workflows
 
     logging.debug("command: {}".format(ctx.command_path.replace(" ", ".")))
@@ -171,13 +192,19 @@ def workflow_workflows(  # noqa: C901
         logging.debug("{param}: {value}".format(param=p, value=ctx.params[p]))
     type = "interactive" if sessions else "batch"
 
-    status_filter = None
+    status_filter = RUN_STATUSES.copy()
+    if not show_deleted_runs and not show_all:
+        status_filter.remove("deleted")
+
     search_filter = None
     if filters:
         filter_names = ["name", "status"]
-        status_filter, search_filter = parse_filter_parameters(filters, filter_names)
-    if _format:
-        parsed_format_filters = parse_format_parameters(_format)
+        provided_status_filter, search_filter = parse_filter_parameters(
+            filters, filter_names
+        )
+        if provided_status_filter:
+            status_filter = provided_status_filter
+
     try:
         response = get_workflows(
             access_token,
@@ -194,6 +221,7 @@ def workflow_workflows(  # noqa: C901
         verbose_headers = ["id", "user"]
         workspace_size_header = ["size"]
         progress_header = ["progress"]
+        duration_header = ["duration"]
         headers = {
             "batch": ["name", "run_number", "created", "started", "ended", "status"],
             "interactive": [
@@ -211,14 +239,16 @@ def workflow_workflows(  # noqa: C901
             headers[type] += workspace_size_header
         if verbose or include_progress:
             headers[type] += progress_header
+        if verbose or include_duration:
+            headers[type] += duration_header
+
         data = []
         for workflow in response:
             workflow["size"] = workflow["size"][human_readable_or_raw]
-            if workflow["status"] == "deleted" and not show_all:
-                continue
             name, run_number = get_workflow_name_and_run_number(workflow["name"])
             workflow["name"] = name
             workflow["run_number"] = run_number
+            workflow["duration"] = get_workflow_duration(workflow)
             if type == "interactive":
                 workflow["session_uri"] = format_session_uri(
                     reana_server_url=ctx.obj.reana_server_url,
@@ -239,36 +269,28 @@ def workflow_workflows(  # noqa: C901
                     value = workflow.get(header)
                 row.append(value)
             data.append(row)
+
+        # Sort by given column, making sure that `None` is at the bottom of the list.
         sort_column_id = 2
         if sort_columm_name.lower() in headers[type]:
             sort_column_id = headers[type].index(sort_columm_name.lower())
-        data = sorted(data, key=lambda x: x[sort_column_id], reverse=True)
+        data = sorted(
+            data,
+            key=lambda x: (x[sort_column_id] is not None, x[sort_column_id]),
+            reverse=True,
+        )
+
+        # Substitute `None` with "-"
+        for row in data:
+            for i, value in enumerate(row):
+                row[i] = value or "-"
+
         workflow_ids = ["{0}.{1}".format(w[0], w[1]) for w in data]
         if os.getenv("REANA_WORKON", "") in workflow_ids:
             active_workflow_idx = workflow_ids.index(os.getenv("REANA_WORKON", ""))
-            for idx, row in enumerate(data):
-                if idx == active_workflow_idx:
-                    run_number = str(data[idx][headers[type].index("run_number")])
-                    run_number += " *"
-        tablib_data = tablib.Dataset()
-        tablib_data.headers = headers[type]
-        for row in data:
-            tablib_data.append(row=row, tags=row)
+            data[active_workflow_idx][headers[type].index("run_number")] += " *"
 
-        if _format:
-            tablib_data, filtered_headers = format_data(
-                parsed_format_filters, headers[type], tablib_data
-            )
-            if output_format:
-                display_message(json.dumps(tablib_data))
-            else:
-                tablib_data = [list(item.values()) for item in tablib_data]
-                click_table_printer(filtered_headers, filtered_headers, tablib_data)
-        else:
-            if output_format:
-                display_message(tablib_data.export(output_format))
-            else:
-                click_table_printer(headers[type], _format, data)
+        display_formatted_output(data, headers[type], _format, output_format)
 
     except Exception as e:
         logging.debug(traceback.format_exc())
@@ -315,7 +337,7 @@ def workflow_create(ctx, file, name, skip_validation, access_token):  # noqa: D3
     working directory, or supplied via command-line -f option, see examples
     below.
 
-    Examples: \n
+    Examples:\n
     \t $ reana-client create\n
     \t $ reana-client create -w myanalysis\n
     \t $ reana-client create -w myanalysis -f myreana.yaml\n
@@ -334,19 +356,23 @@ def workflow_create(ctx, file, name, skip_validation, access_token):  # noqa: D3
         display_message("Workflow name cannot be a valid UUIDv4", msg_type="error")
         sys.exit(1)
 
+    specification_filename = click.format_filename(file)
+
     try:
-        reana_specification = load_reana_spec(
-            click.format_filename(file),
+        reana_specification = load_validate_reana_spec(
+            specification_filename,
             access_token=access_token,
             skip_validation=skip_validation,
             server_capabilities=True,
         )
         logging.info("Connecting to {0}".format(get_api_url()))
         response = create_workflow(reana_specification, name, access_token)
-        click.echo(click.style(response["workflow_name"], fg="green"))
+        workflow_name = response["workflow_name"]
+
+        click.echo(click.style(workflow_name, fg="green"))
         # check if command is called from wrapper command
         if "invoked_by_subcommand" in ctx.parent.__dict__:
-            ctx.parent.workflow_name = response["workflow_name"]
+            ctx.parent.workflow_name = workflow_name
     except Exception as e:
         logging.debug(traceback.format_exc())
         logging.debug(str(e))
@@ -355,6 +381,14 @@ def workflow_create(ctx, file, name, skip_validation, access_token):  # noqa: D3
         )
         sys.exit(1)
 
+    # upload specification file by default
+    ctx.invoke(
+        upload_files,
+        workflow=workflow_name,
+        filenames=(specification_filename,),
+        access_token=access_token,
+    )
+
 
 @workflow_execution_group.command("start")
 @add_workflow_option
@@ -400,8 +434,8 @@ def workflow_start(
     options can be repetitive. For example, to disable caching for the Serial
     workflow engine, you can set ``-o CACHE=off``.
 
-    Examples: \n
-    \t $ reana-client start -w myanalysis.42 -p sleeptime=10 -p myparam=4 \n
+    Examples:\n
+    \t $ reana-client start -w myanalysis.42 -p sleeptime=10 -p myparam=4\n
     \t $ reana-client start -w myanalysis.42 -p myparam1=myvalue1 -o CACHE=off
     """
     from reana_client.utils import get_api_url
@@ -411,6 +445,15 @@ def workflow_start(
         start_workflow,
     )
 
+    def display_status(workflow: str, current_status: str):
+        """Display the current status of the workflow."""
+        status_msg = get_workflow_status_change_msg(workflow, current_status)
+        if current_status in ["deleted", "failed", "stopped"]:
+            display_message(status_msg, msg_type="error")
+            sys.exit(1)
+        else:
+            display_message(status_msg, msg_type="success")
+
     logging.debug("command: {}".format(ctx.command_path.replace(" ", ".")))
     for p in ctx.params:
         logging.debug("{param}: {value}".format(param=p, value=ctx.params[p]))
@@ -443,34 +486,28 @@ def workflow_start(
             logging.info("Connecting to {0}".format(get_api_url()))
             response = start_workflow(workflow, access_token, parsed_parameters)
             current_status = get_workflow_status(workflow, access_token).get("status")
-            display_message(
-                get_workflow_status_change_msg(workflow, current_status),
-                msg_type="success",
-            )
+            display_status(workflow, current_status)
+
             if follow:
-                while "running" in current_status:
+                # keep printing the current status of the workflow
+                while current_status in ["pending", "queued", "running"]:
                     time.sleep(TIMECHECK)
                     current_status = get_workflow_status(workflow, access_token).get(
                         "status"
                     )
-                    display_message(
-                        get_workflow_status_change_msg(workflow, current_status),
-                        msg_type="success",
-                    )
-                    if "finished" in current_status:
-                        if follow:
-                            display_message(
-                                "Listing workflow output files...", msg_type="info",
-                            )
-                            ctx.invoke(
-                                get_files,
-                                workflow=workflow,
-                                access_token=access_token,
-                                output_format="url",
-                            )
-                        sys.exit(0)
-                    elif "failed" in current_status or "stopped" in current_status:
-                        sys.exit(1)
+                    display_status(workflow, current_status)
+
+                    if current_status == "finished":
+                        display_message(
+                            "Listing workflow output files...", msg_type="info"
+                        )
+                        ctx.invoke(
+                            get_files,
+                            workflow=workflow,
+                            access_token=access_token,
+                            output_format="url",
+                            human_readable_or_raw="raw",
+                        )
         except Exception as e:
             logging.debug(traceback.format_exc())
             logging.debug(str(e))
@@ -530,8 +567,8 @@ def workflow_restart(
     ``-o`` or ``--options``.  The input parameters and operational options can be
     repetitive.
 
-    Examples: \n
-    \t $ reana-client restart -w myanalysis.42 -p sleeptime=10 -p myparam=4 \n
+    Examples:\n
+    \t $ reana-client restart -w myanalysis.42 -p sleeptime=10 -p myparam=4\n
     \t $ reana-client restart -w myanalysis.42 -p myparam=myvalue\n
     \t $ reana-client restart -w myanalysis.42 -o TARGET=gendata\n
     \t $ reana-client restart -w myanalysis.42 -o FROM=fitdata
@@ -553,61 +590,70 @@ def workflow_restart(
         "restart": True,
     }
     if file:
-        parsed_parameters["reana_specification"] = load_reana_spec(
+        specification_filename = click.format_filename(file)
+        parsed_parameters["reana_specification"] = load_validate_reana_spec(
             click.format_filename(file)
         )
-    if workflow:
-        if parameters or options:
-            try:
-                if "reana_specification" in parsed_parameters:
-                    workflow_type = parsed_parameters["reana_specification"][
-                        "workflow"
-                    ]["type"]
-                    original_parameters = (
-                        parsed_parameters["reana_specification"]
-                        .get("inputs", {})
-                        .get("parameters", {})
-                    )
-                else:
-                    response = get_workflow_parameters(workflow, access_token)
-                    workflow_type = response["type"]
-                    original_parameters = response["parameters"]
+        # upload new specification
+        ctx.invoke(
+            upload_files,
+            workflow=workflow,
+            filenames=(specification_filename,),
+            access_token=access_token,
+        )
 
-                parsed_parameters["operational_options"] = validate_operational_options(
-                    workflow_type, parsed_parameters["operational_options"]
-                )
-                parsed_parameters["input_parameters"] = validate_input_parameters(
-                    parsed_parameters["input_parameters"], original_parameters
-                )
-
-            except REANAValidationError as e:
-                display_message(e.message, msg_type="error")
-                sys.exit(1)
-            except Exception as e:
-                display_message(
-                    "Could not apply given input parameters: "
-                    "{0} \n{1}".format(parameters, str(e)),
-                    msg_type="error",
-                )
-                sys.exit(1)
+    if parameters or options:
         try:
-            logging.info("Connecting to {0}".format(get_api_url()))
-            response = start_workflow(workflow, access_token, parsed_parameters)
-            workflow = response["workflow_name"] + "." + str(response["run_number"])
-            current_status = get_workflow_status(workflow, access_token).get("status")
-            display_message(
-                get_workflow_status_change_msg(workflow, current_status),
-                msg_type="success",
+            if "reana_specification" in parsed_parameters:
+                workflow_type = parsed_parameters["reana_specification"]["workflow"][
+                    "type"
+                ]
+                original_parameters = (
+                    parsed_parameters["reana_specification"]
+                    .get("inputs", {})
+                    .get("parameters", {})
+                )
+            else:
+                response = get_workflow_parameters(workflow, access_token)
+                workflow_type = response["type"]
+                original_parameters = response["parameters"]
+
+            parsed_parameters["operational_options"] = validate_operational_options(
+                workflow_type, parsed_parameters["operational_options"]
             )
+            parsed_parameters["input_parameters"] = validate_input_parameters(
+                parsed_parameters["input_parameters"], original_parameters
+            )
+
+        except REANAValidationError as e:
+            display_message(e.message, msg_type="error")
+            sys.exit(1)
         except Exception as e:
-            logging.debug(traceback.format_exc())
-            logging.debug(str(e))
             display_message(
-                "Cannot start workflow {}: \n{}".format(workflow, str(e)),
+                "Could not apply given input parameters: "
+                "{0} \n{1}".format(parameters, str(e)),
                 msg_type="error",
             )
             sys.exit(1)
 
+    try:
+        logging.info("Connecting to {0}".format(get_api_url()))
+        response = start_workflow(workflow, access_token, parsed_parameters)
+        workflow = response["workflow_name"] + "." + str(response["run_number"])
+        current_status = get_workflow_status(workflow, access_token).get("status")
+        display_message(
+            get_workflow_status_change_msg(workflow, current_status),
+            msg_type="success",
+        )
+    except Exception as e:
+        logging.debug(traceback.format_exc())
+        logging.debug(str(e))
+        display_message(
+            "Cannot start workflow {}: \n{}".format(workflow, str(e)),
+            msg_type="error",
+        )
+        sys.exit(1)
+
 
 @workflow_execution_group.command("status")
 @add_workflow_option
@@ -625,12 +671,20 @@ def workflow_restart(
     default=None,
     help="Get output in JSON format.",
 )
+@click.option(
+    "--include-duration",
+    "include_duration",
+    is_flag=True,
+    default=False,
+    help="Include the duration of the workflow in seconds. In case the workflow is in "
+    "progress, its duration as of now will be shown.",
+)
 @add_access_token_options
 @check_connection
 @click.option("-v", "--verbose", count=True, help="Set status information verbosity.")
 @click.pass_context
 def workflow_status(  # noqa: C901
-    ctx, workflow, _format, output_format, access_token, verbose
+    ctx, workflow, _format, output_format, include_duration, access_token, verbose
 ):  # noqa: D301
     """Get status of a workflow.
 
@@ -638,11 +692,10 @@ def workflow_status(  # noqa: C901
     be created, queued, running, failed, etc. You can increase verbosity or
     filter retrieved information by passing appropriate command-line options.
 
-    Examples: \n
-    \t $ reana-client status -w myanalysis.42 \n
+    Examples:\n
+    \t $ reana-client status -w myanalysis.42\n
     \t $ reana-client status -w myanalysis.42 -v --json
     """
-    import tablib
     from reana_client.api.client import get_workflow_status
 
     def render_progress(finished_jobs, total_jobs):
@@ -651,7 +704,7 @@ def workflow_status(  # noqa: C901
         else:
             return "-/-"
 
-    def add_data_from_reponse(row, data, headers):
+    def add_data_from_response(row, data, headers):
         name, run_number = get_workflow_name_and_run_number(row["name"])
         total_jobs = row["progress"].get("total")
         if total_jobs:
@@ -714,47 +767,32 @@ def workflow_status(  # noqa: C901
     logging.debug("command: {}".format(ctx.command_path.replace(" ", ".")))
     for p in ctx.params:
         logging.debug("{param}: {value}".format(param=p, value=ctx.params[p]))
-    if workflow:
-        try:
-            if _format:
-                parsed_filters = parse_format_parameters(_format)
-                _format = [item["column_name"] for item in parsed_filters]
-            response = get_workflow_status(workflow, access_token)
-            headers = ["name", "run_number", "created", "status"]
-            verbose_headers = ["id", "user", "command"]
-            data = []
-            if not isinstance(response, list):
-                response = [response]
-            for workflow in response:
-                add_data_from_reponse(workflow, data, headers)
-                if verbose:
-                    headers += verbose_headers
-                    add_verbose_data_from_response(
-                        workflow, verbose_headers, headers, data
-                    )
-
-            if output_format:
-                tablib_data = tablib.Dataset()
-                tablib_data.headers = headers
-                for row in data:
-                    tablib_data.append(row)
-
-                if _format:
-                    tablib_data = tablib_data.subset(rows=None, cols=list(_format))
-
-                display_message(tablib_data.export(output_format))
-            else:
-                click_table_printer(headers, _format, data)
-
-        except Exception as e:
-            logging.debug(traceback.format_exc())
-            logging.debug(str(e))
-            display_message(
-                "Cannot retrieve the status of a workflow {}: \n"
-                "{}".format(workflow, str(e)),
-                msg_type="error",
+    try:
+        workflow_response = get_workflow_status(workflow, access_token)
+        headers = ["name", "run_number", "created", "status"]
+        verbose_headers = ["id", "user", "command"]
+        data = []
+        add_data_from_response(workflow_response, data, headers)
+        if verbose:
+            headers += verbose_headers
+            add_verbose_data_from_response(
+                workflow_response, verbose_headers, headers, data
             )
-            sys.exit(1)
+        if verbose or include_duration:
+            headers += ["duration"]
+            data[-1] += [get_workflow_duration(workflow_response) or "-"]
+
+        display_formatted_output(data, headers, _format, output_format)
+
+    except Exception as e:
+        logging.debug(traceback.format_exc())
+        logging.debug(str(e))
+        display_message(
+            "Cannot retrieve the status of a workflow {}: \n"
+            "{}".format(workflow, str(e)),
+            msg_type="error",
+        )
+        sys.exit(1)
 
 
 @workflow_execution_group.command("logs")
@@ -786,7 +824,7 @@ def workflow_logs(
     only finished steps of the workflow are returned, the logs of the currently
     processed step is not returned until it is finished.
 
-    Examples: \n
+    Examples:\n
     \t $ reana-client logs -w myanalysis.42
     \t $ reana-client logs -w myanalysis.42 -s 1st_step
     """
@@ -813,7 +851,8 @@ def workflow_logs(
                         display_message(
                             "Filter '{}' is not valid.\n"
                             "Available filters are '{}'.".format(
-                                key, "' '".join(sorted(available_filters.keys())),
+                                key,
+                                "' '".join(sorted(available_filters.keys())),
                             ),
                             msg_type="error",
                         )
@@ -926,7 +965,7 @@ def workflow_validate(
     The ``validate`` command allows to check syntax and validate the reana.yaml
     workflow specification file.
 
-    Examples: \n
+    Examples:\n
     \t $ reana-client validate -f reana.yaml
     """
     if server_capabilities:
@@ -939,7 +978,7 @@ def workflow_validate(
     for p in ctx.params:
         logging.debug("{param}: {value}".format(param=p, value=ctx.params[p]))
     try:
-        load_reana_spec(
+        load_validate_reana_spec(
             click.format_filename(file),
             access_token=access_token,
             skip_validate_environments=not environments,
@@ -987,7 +1026,7 @@ def workflow_stop(ctx, workflow, force_stop, access_token):  # noqa: D301
     should be therefore used with care, only if you are absolutely sure that
     there is no point in continuing the running the workflow.
 
-    Example: \n
+    Example:\n
     \t $ reana-client stop -w myanalysis.42 --force
     """
     from reana_client.api.client import stop_workflow
@@ -1006,7 +1045,8 @@ def workflow_stop(ctx, workflow, force_stop, access_token):  # noqa: D301
             logging.info("Sending a request to stop workflow {}".format(workflow))
             stop_workflow(workflow, force_stop, access_token)
             display_message(
-                get_workflow_status_change_msg(workflow, "stopped"), msg_type="success",
+                get_workflow_status_change_msg(workflow, "stopped"),
+                msg_type="success",
             )
         except Exception as e:
             logging.debug(traceback.format_exc())
@@ -1079,8 +1119,8 @@ def workflow_run(
     The ``run`` command allows to create a new workflow, upload its input files
     and start it in one command.
 
-    Examples: \n
-    \t $ reana-client run -w myanalysis-test-small -p myparam=mysmallvalue \n
+    Examples:\n
+    \t $ reana-client run -w myanalysis-test-small -p myparam=mysmallvalue\n
     \t $ reana-client run -w myanalysis-test-big -p myparam=mybigvalue
     """
     # set context parameters for subcommand
@@ -1121,7 +1161,7 @@ def workflow_run(
 )
 @click.option(
     "--include-workspace",
-    "workspace",
+    "should_delete_workspace",
     is_flag=True,
     help="Delete workspace from REANA.",
 )
@@ -1129,24 +1169,24 @@ def workflow_run(
 @add_access_token_options
 @check_connection
 @click.pass_context
-def workflow_delete(ctx, workflow, all_runs, workspace, access_token):  # noqa: D301
+def workflow_delete(
+    ctx, workflow: str, all_runs: bool, should_delete_workspace: bool, access_token: str
+):  # noqa: D301
     """Delete a workflow.
 
-    The ``delete`` command allows to remove workflow runs from the database and
-    the workspace. By default, the command removes the workflow and all its
-    cached information and hides the workflow from the workflow list. Note that
-    workflow workspace will still be accessible until you use
-    ``--include-workspace`` flag. Note also that you can remove all past runs of
-    a workflow by specifying ``--include-all-runs`` flag.
+    The ``delete`` command removes workflow run(s) from the database.
+    Note that the workspace will always be deleted, even when ``--include-workspace`` is not specified.
+    Note also that you can remove all past runs of a workflow by specifying ``--include-all-runs`` flag.
 
-    Example: \n
-    \t $ reana-client delete -w myanalysis.42 \n
-    \t $ reana-client delete -w myanalysis.42 --include-all-runs \n
-    \t $ reana-client delete -w myanalysis.42 --include-workspace
+    Example:\n
+    \t $ reana-client delete -w myanalysis.42\n
+    \t $ reana-client delete -w myanalysis.42 --include-all-runs
     """
     from reana_client.api.client import delete_workflow
     from reana_client.utils import get_api_url
 
+    should_delete_workspace = True
+
     logging.debug("command: {}".format(ctx.command_path.replace(" ", ".")))
     for p in ctx.params:
         logging.debug("{param}: {value}".format(param=p, value=ctx.params[p]))
@@ -1154,7 +1194,7 @@ def workflow_delete(ctx, workflow, all_runs, workspace, access_token):  # noqa:
     if workflow:
         try:
             logging.info("Connecting to {0}".format(get_api_url()))
-            delete_workflow(workflow, all_runs, workspace, access_token)
+            delete_workflow(workflow, all_runs, should_delete_workspace, access_token)
             if all_runs:
                 message = "All workflows named '{}' have been deleted.".format(
                     workflow.split(".")[0]
@@ -1208,8 +1248,8 @@ def workflow_diff(
     workflow_b, which must be provided as arguments. The output will show the
     difference in workflow run parameters, the generated files, the logs, etc.
 
-    Examples: \n
-    \t $ reana-client diff myanalysis.42 myotheranalysis.43 \n
+    Examples:\n
+    \t $ reana-client diff myanalysis.42 myotheranalysis.43\n
     \t $ reana-client diff myanalysis.42 myotheranalysis.43 --brief
     """
     from reana_client.api.client import diff_workflows
