@@ -9,6 +9,7 @@
 """REANA client workflow tests."""
 
 import json
+from typing import List
 
 import pytest
 import yaml
@@ -18,6 +19,7 @@ from pytest_reana.test_utils import make_mock_api_client
 from reana_commons.config import INTERACTIVE_SESSION_TYPES
 
 from reana_client.api.client import create_workflow_from_json
+from reana_client.config import RUN_STATUSES
 from reana_client.cli import cli
 from reana_client.utils import get_workflow_status_change_msg
 
@@ -48,14 +50,14 @@ def test_workflows_server_ok():
         "items": [
             {
                 "status": "running",
-                "created": "2018-06-13T09:47:35.66097",
+                "created": "2018-06-13T09:47:35",
                 "user": "00000000-0000-0000-0000-000000000000",
                 "name": "mytest.1",
                 "id": "256b25f4-4cfb-4684-b7a8-73872ef455a1",
                 "size": {"raw": 0, "human_readable": "0 Bytes"},
                 "progress": {
-                    "run_started_at": "2018-06-13T09:47:40.28223",
-                    "run_finished_at": "2018-06-13T10:30:03.70303",
+                    "run_started_at": "2018-06-13T09:47:40",
+                    "run_finished_at": "2018-06-13T10:30:03",
                 },
             }
         ]
@@ -80,25 +82,57 @@ def test_workflows_server_ok():
             assert message in result.output
 
 
+@pytest.mark.parametrize(
+    "cli_options,expected_status_filter",
+    [
+        ([], [status for status in RUN_STATUSES if status != "deleted"]),
+        (["--show-deleted-runs"], RUN_STATUSES),
+        (["--all"], RUN_STATUSES),
+        (["--filter", "status=deleted"], ["deleted"]),
+        (["--filter", "status=finished", "--show-deleted-runs"], ["finished"]),
+        (["--filter", "status=finished", "--all"], ["finished"]),
+        (
+            ["--filter", "name=myworkflow"],
+            [status for status in RUN_STATUSES if status != "deleted"],
+        ),
+        (["--filter", "name=myworkflow", "--show-deleted-runs"], RUN_STATUSES),
+        (["--filter", "name=myworkflow", "--all"], RUN_STATUSES),
+    ],
+)
+def test_deleted_workflows(cli_options: List[str], expected_status_filter: List[str]):
+    """Test whatever deleted workflows are displayed correctly depending on options and filters."""
+    # we do not care what response is in this case
+    response = {"items": []}
+    env = {"REANA_SERVER_URL": "localhost"}
+    reana_token = "000000"
+    runner = CliRunner(env=env)
+    with runner.isolation():
+        with patch("reana_client.api.client.get_workflows") as mock_get_workflows:
+            mock_get_workflows.return_value = response
+            runner.invoke(cli, ["list", "-t", reana_token] + cli_options)
+            kwargs = mock_get_workflows.call_args.kwargs
+            assert kwargs["status"] == expected_status_filter
+
+
 def test_workflows_sorting():
     """Test workflows sorting."""
     response = {
         "items": [
             {
                 "status": "running",
-                "created": "2018-06-13T09:47:35.66097",
+                "created": "2018-06-13T09:47:35",
                 "user": "00000000-0000-0000-0000-000000000000",
                 "name": "mytest.1",
                 "id": "256b25f4-4cfb-4684-b7a8-73872ef455a1",
                 "progress": {
-                    "run_started_at": "2018-06-13T09:47:40.28223",
-                    "run_finished_at": "2018-06-13T10:30:03.70303",
+                    "run_started_at": "2018-06-13T09:47:40",
+                    "run_finished_at": "2018-06-13T10:30:03",
                 },
                 "size": {"raw": 0, "human_readable": "0 Bytes"},
             },
             {
                 "status": "running",
-                "created": "2018-06-13T09:55:35.66097",
+                "created": "2018-06-13T09:55:35",
                 "user": "00000000-0000-0000-0000-000000000000",
                 "name": "mytest.2",
                 "id": "256b25f4-4cfb-4684-b7a8-73872ef455a2",
@@ -122,12 +156,8 @@ def test_workflows_sorting():
                 cli, ["list", "-t", reana_token, "--sort", "run_number"]
             )
             message = (
-                "mytest   2            2018-06-13T09:55:35.66097   -"
-                "                           -"
-                "                           running\n"
-                "mytest   1            2018-06-13T09:47:35.66097   "
-                "2018-06-13T09:47:40.28223   2018-06-13T10:30:03.70303"
-                "   running"
+                "mytest   2            2018-06-13T09:55:35   -                     -                     running\n"
+                "mytest   1 *          2018-06-13T09:47:35   2018-06-13T09:47:40   2018-06-13T10:30:03   running"
             )
             assert result.exit_code == 0
             assert message in result.output
@@ -416,7 +446,8 @@ def test_workflows_filter():
             make_mock_api_client("reana-server")(mock_response, mock_http_response),
         ):
             result = runner.invoke(
-                cli, ["list", "-t", reana_token, "--json", "--filter", filter],
+                cli,
+                ["list", "-t", reana_token, "--json", "--filter", filter],
             )
             json_response = json.loads(result.output)
             assert result.exit_code == 0
@@ -454,7 +485,7 @@ def test_workflow_create_successful(create_yaml_workflow_schema):
         with patch(
             "reana_client.api.client.current_rs_api_client",
             make_mock_api_client("reana-server")(mock_response, mock_http_response),
-        ):
+        ), patch("reana_client.api.client.requests.post") as upload_request:
             with runner.isolated_filesystem():
                 with open("reana.yaml", "w") as f:
                     f.write(create_yaml_workflow_schema)
@@ -464,6 +495,9 @@ def test_workflow_create_successful(create_yaml_workflow_schema):
                 assert result.exit_code == 0
                 assert response["workflow_name"] in result.output
 
+                upload_request.assert_called_once()
+                assert "File /reana.yaml was successfully uploaded." in result.output
+
 
 def test_workflow_create_not_valid_name(create_yaml_workflow_schema):
     """Test workflow create when creation is successfull."""
@@ -509,10 +543,19 @@ def test_create_workflow_from_json(create_yaml_workflow_schema):
 
 
 @pytest.mark.parametrize(
-    "status",
-    ["created", "running", "finished", "failed", "deleted", "stopped", "queued"],
+    "status, exit_code",
+    [
+        ("created", 0),
+        ("pending", 0),
+        ("queued", 0),
+        ("running", 0),
+        ("finished", 0),
+        ("failed", 1),
+        ("deleted", 1),
+        ("stopped", 1),
+    ],
 )
-def test_workflow_start_successful(status):
+def test_workflow_start_successful(status, exit_code):
     """Test workflow start when creation is successfull."""
     workflow_name = "mytest.1"
     response = {
@@ -538,14 +581,21 @@ def test_workflow_start_successful(status):
             result = runner.invoke(
                 cli, ["start", "-t", reana_token, "-w", response["workflow_name"]]
             )
-            assert result.exit_code == 0
+            assert result.exit_code == exit_code
             assert expected_message in result.output
 
 
 @pytest.mark.parametrize(
     "initial_status, final_status, exit_code",
-    [("running", "finished", 0), ("running", "failed", 1), ("running", "stopped", 1)],
+    [
+        ("running", "finished", 0),
+        ("running", "failed", 1),
+        ("running", "stopped", 1),
+        ("queued", "finished", 0),
+        ("pending", "deleted", 1),
+    ],
 )
+@patch("reana_client.cli.workflow.TIMECHECK", 0)
 def test_workflow_start_follow(initial_status, final_status, exit_code):
     """Test start workflow with follow flag."""
     workflow_name = "mytest.1"
@@ -606,6 +656,8 @@ def test_workflow_start_follow(initial_status, final_status, exit_code):
             assert result.exit_code == exit_code
             assert initial_expected_message in result.output
             assert final_Expected_message in result.output
+            if final_status == "finished":
+                assert "Listing workflow output files..." in result.output
 
 
 def test_workflows_validate(create_yaml_workflow_schema):
@@ -618,7 +670,8 @@ def test_workflows_validate(create_yaml_workflow_schema):
         with open("reana.yaml", "w") as f:
             f.write(create_yaml_workflow_schema)
         result = runner.invoke(
-            cli, ["validate", "-t", reana_token, "--file", "reana.yaml"],
+            cli,
+            ["validate", "-t", reana_token, "--file", "reana.yaml"],
         )
         assert result.exit_code == 0
         assert message in result.output
@@ -684,7 +737,8 @@ def test_run(
         with open(reana_workflow_schema, "w") as f:
             f.write(create_yaml_workflow_schema)
         runner.invoke(
-            cli, ["run", "-t", reana_token, "-f", reana_workflow_schema],
+            cli,
+            ["run", "-t", reana_token, "-f", reana_workflow_schema],
         )
     assert workflow_create_mock.called is True
     assert upload_file_mock.called is True
