@@ -11,14 +11,16 @@
 import pytest
 import yaml
 
-from reana_client.validation.compute_backends import (
-    SerialComputeBackendValidator,
-    YadageComputeBackendValidator,
-    SnakemakeComputeBackendValidator,
-    CWLComputeBackendValidator,
-    validate_compute_backends,
+from reana_commons.errors import REANAValidationError
+from reana_commons.validation.compute_backends import (
+    ComputeBackendValidatorSerial,
+    ComputeBackendValidatorYadage,
+    ComputeBackendValidatorSnakemake,
+    ComputeBackendValidatorCWL,
 )
 
+from reana_client.validation.compute_backends import validate_compute_backends
+
 
 @pytest.mark.parametrize(
     "compute_backend, supported_backends, valid",
@@ -43,13 +45,12 @@ def test_validate_compute_backends_serial(
         captured = capsys.readouterr()
         assert "SUCCESS: Workflow compute backends appear to be valid." in captured.out
     else:
-        validator = SerialComputeBackendValidator(
+        validator = ComputeBackendValidatorSerial(
             workflow_steps=workflow_steps, supported_backends=supported_backends
         )
-        with pytest.raises(SystemExit):
+        with pytest.raises(REANAValidationError) as e:
             validator.validate()
-        captured = capsys.readouterr()
-        assert "is not supported." in captured.err
+        assert "is not supported." in e.value.message
 
 
 @pytest.mark.parametrize(
@@ -77,13 +78,12 @@ def test_validate_compute_backends_yadage(
         captured = capsys.readouterr()
         assert "SUCCESS: Workflow compute backends appear to be valid." in captured.out
     else:
-        validator = YadageComputeBackendValidator(
+        validator = ComputeBackendValidatorYadage(
             workflow_steps=workflow_steps, supported_backends=supported_backends
         )
-        with pytest.raises(SystemExit):
+        with pytest.raises(REANAValidationError) as e:
             validator.validate()
-        captured = capsys.readouterr()
-        assert "is not supported." in captured.err
+        assert "is not supported." in e.value.message
 
 
 @pytest.mark.parametrize(
@@ -109,13 +109,12 @@ def test_validate_compute_backends_snakemake(
         captured = capsys.readouterr()
         assert "SUCCESS: Workflow compute backends appear to be valid." in captured.out
     else:
-        validator = SnakemakeComputeBackendValidator(
+        validator = ComputeBackendValidatorSnakemake(
             workflow_steps=workflow_steps, supported_backends=supported_backends
         )
-        with pytest.raises(SystemExit):
+        with pytest.raises(REANAValidationError) as e:
             validator.validate()
-        captured = capsys.readouterr()
-        assert "is not supported." in captured.err
+        assert "is not supported." in e.value.message
 
 
 @pytest.mark.parametrize(
@@ -129,22 +128,27 @@ def test_validate_compute_backends_snakemake(
     ],
 )
 def test_validate_compute_backends_cwl(
-    compute_backend, supported_backends, valid, cwl_workflow_spec_loaded, capsys,
+    compute_backend,
+    supported_backends,
+    valid,
+    cwl_workflow_spec_loaded,
+    capsys,
 ):
     """Validate compute backends for CWL workflows."""
     reana_yaml = cwl_workflow_spec_loaded
     workflow_steps = reana_yaml["workflow"]["specification"]["$graph"]
-    workflow_steps[0]["steps"][0]["hints"] = [{"compute_backend": compute_backend}]
+    workflow_steps[0]["steps"][0]["hints"] = [
+        {"class": "reana", "compute_backend": compute_backend}
+    ]
 
     if valid:
         validate_compute_backends(reana_yaml, supported_backends)
         captured = capsys.readouterr()
         assert "SUCCESS: Workflow compute backends appear to be valid." in captured.out
     else:
-        validator = CWLComputeBackendValidator(
+        validator = ComputeBackendValidatorCWL(
             workflow_steps=workflow_steps, supported_backends=supported_backends
         )
-        with pytest.raises(SystemExit):
+        with pytest.raises(REANAValidationError) as e:
             validator.validate()
-        captured = capsys.readouterr()
-        assert "is not supported." in captured.err
+        assert "is not supported." in e.value.message
